cgroup: s/cgroup_subsys_state/cgroup_css/ s/task_subsys_state/task_css/
authorTejun Heo <tj@kernel.org>
Fri, 9 Aug 2013 00:11:22 +0000 (20:11 -0400)
committerTejun Heo <tj@kernel.org>
Fri, 9 Aug 2013 00:11:22 +0000 (20:11 -0400)
The names of the two struct cgroup_subsys_state accessors -
cgroup_subsys_state() and task_subsys_state() - are somewhat awkward.
The former clashes with the type name and the latter doesn't even
indicate it's somehow related to cgroup.

We're about to revamp large portion of cgroup API, so, let's rename
them so that they're less awkward.  Most per-controller usages of the
accessors are localized in accessor wrappers and given the amount of
scheduled changes, this isn't gonna add any noticeable headache.

Rename cgroup_subsys_state() to cgroup_css() and task_subsys_state()
to task_css().  This patch is pure rename.

Signed-off-by: Tejun Heo <tj@kernel.org>
Acked-by: Li Zefan <lizefan@huawei.com>
18 files changed:
block/blk-cgroup.h
fs/bio.c
include/linux/cgroup.h
include/net/cls_cgroup.h
include/net/netprio_cgroup.h
kernel/cgroup.c
kernel/cgroup_freezer.c
kernel/cpuset.c
kernel/events/core.c
kernel/sched/core.c
kernel/sched/cpuacct.c
kernel/sched/sched.h
mm/hugetlb_cgroup.c
mm/memcontrol.c
mm/vmpressure.c
net/core/netprio_cgroup.c
net/sched/cls_cgroup.c
security/device_cgroup.c

index 8056c03a3382f595212530f6bd1c4dd1a5282ac8..628e50f6f8a88092d2c41c075291edceb1b54f9e 100644 (file)
@@ -181,14 +181,13 @@ void blkg_conf_finish(struct blkg_conf_ctx *ctx);
 
 static inline struct blkcg *cgroup_to_blkcg(struct cgroup *cgroup)
 {
-       return container_of(cgroup_subsys_state(cgroup, blkio_subsys_id),
+       return container_of(cgroup_css(cgroup, blkio_subsys_id),
                            struct blkcg, css);
 }
 
 static inline struct blkcg *task_blkcg(struct task_struct *tsk)
 {
-       return container_of(task_subsys_state(tsk, blkio_subsys_id),
-                           struct blkcg, css);
+       return container_of(task_css(tsk, blkio_subsys_id), struct blkcg, css);
 }
 
 static inline struct blkcg *bio_blkcg(struct bio *bio)
index 94bbc04dba77053bb47d3d8b793a3a8218f0a0d2..8e0348f6e5bdd2173b5bc18d71f9692bca944f1f 100644 (file)
--- a/fs/bio.c
+++ b/fs/bio.c
@@ -1946,7 +1946,7 @@ int bio_associate_current(struct bio *bio)
 
        /* associate blkcg if exists */
        rcu_read_lock();
-       css = task_subsys_state(current, blkio_subsys_id);
+       css = task_css(current, blkio_subsys_id);
        if (css && css_tryget(css))
                bio->bi_css = css;
        rcu_read_unlock();
index 44dd422d7e9bbcb7b699cfc7e49032bd53c50991..552c5feef733c4eadae9a50f38412620beaf99b8 100644 (file)
@@ -647,8 +647,15 @@ struct cgroup_subsys {
 #undef IS_SUBSYS_ENABLED
 #undef SUBSYS
 
-static inline struct cgroup_subsys_state *cgroup_subsys_state(
-       struct cgroup *cgrp, int subsys_id)
+/**
+ * cgroup_css - obtain a cgroup's css for the specified subsystem
+ * @cgrp: the cgroup of interest
+ * @subsys_id: the subsystem of interest
+ *
+ * Return @cgrp's css (cgroup_subsys_state) associated with @subsys_id.
+ */
+static inline struct cgroup_subsys_state *cgroup_css(struct cgroup *cgrp,
+                                                    int subsys_id)
 {
        return cgrp->subsys[subsys_id];
 }
@@ -678,7 +685,7 @@ extern struct mutex cgroup_mutex;
 #endif
 
 /**
* task_subsys_state_check - obtain css for (task, subsys) w/ extra access conds
  * @task: the target task
  * @subsys_id: the target subsystem ID
  * @__c: extra condition expression to be passed to rcu_dereference_check()
@@ -686,7 +693,7 @@ extern struct mutex cgroup_mutex;
  * Return the cgroup_subsys_state for the (@task, @subsys_id) pair.  The
  * synchronization rules are the same as task_css_set_check().
  */
-#define task_subsys_state_check(task, subsys_id, __c)                  \
+#define task_css_check(task, subsys_id, __c)                           \
        task_css_set_check((task), (__c))->subsys[(subsys_id)]
 
 /**
@@ -701,22 +708,22 @@ static inline struct css_set *task_css_set(struct task_struct *task)
 }
 
 /**
* task_subsys_state - obtain css for (task, subsys)
  * @task: the target task
  * @subsys_id: the target subsystem ID
  *
- * See task_subsys_state_check().
+ * See task_css_check().
  */
-static inline struct cgroup_subsys_state *
-task_subsys_state(struct task_struct *task, int subsys_id)
+static inline struct cgroup_subsys_state *task_css(struct task_struct *task,
+                                                  int subsys_id)
 {
-       return task_subsys_state_check(task, subsys_id, false);
+       return task_css_check(task, subsys_id, false);
 }
 
-static inline struct cgrouptask_cgroup(struct task_struct *task,
-                                              int subsys_id)
+static inline struct cgroup *task_cgroup(struct task_struct *task,
+                                        int subsys_id)
 {
-       return task_subsys_state(task, subsys_id)->cgroup;
+       return task_css(task, subsys_id)->cgroup;
 }
 
 /**
index 0fee0617fb7d243728583ee351de284f36aca14a..52adaa75dac9c72b531554971dd62ef7f7d927fe 100644 (file)
@@ -35,7 +35,7 @@ static inline u32 task_cls_classid(struct task_struct *p)
                return 0;
 
        rcu_read_lock();
-       classid = container_of(task_subsys_state(p, net_cls_subsys_id),
+       classid = container_of(task_css(p, net_cls_subsys_id),
                               struct cgroup_cls_state, css)->classid;
        rcu_read_unlock();
 
@@ -51,7 +51,7 @@ static inline u32 task_cls_classid(struct task_struct *p)
                return 0;
 
        rcu_read_lock();
-       css = task_subsys_state(p, net_cls_subsys_id);
+       css = task_css(p, net_cls_subsys_id);
        if (css)
                classid = container_of(css,
                                       struct cgroup_cls_state, css)->classid;
index 50ab8c26ab59b7ebe840e50d6f696d16f32969b8..8110fa7ae60af65eba870ad7dda767626541ab6c 100644 (file)
@@ -39,7 +39,7 @@ static inline u32 task_netprioidx(struct task_struct *p)
        u32 idx;
 
        rcu_read_lock();
-       css = task_subsys_state(p, net_prio_subsys_id);
+       css = task_css(p, net_prio_subsys_id);
        idx = css->cgroup->id;
        rcu_read_unlock();
        return idx;
@@ -53,7 +53,7 @@ static inline u32 task_netprioidx(struct task_struct *p)
        u32 idx = 0;
 
        rcu_read_lock();
-       css = task_subsys_state(p, net_prio_subsys_id);
+       css = task_css(p, net_prio_subsys_id);
        if (css)
                idx = css->cgroup->id;
        rcu_read_unlock();
index ae4c46834633e1a18a4f3e2f1f8714c5a0fd737b..0b3caa3220cbe91836a5dd72d3a7f3c60c6afd4d 100644 (file)
@@ -81,7 +81,7 @@
  */
 #ifdef CONFIG_PROVE_RCU
 DEFINE_MUTEX(cgroup_mutex);
-EXPORT_SYMBOL_GPL(cgroup_mutex);       /* only for task_subsys_state_check() */
+EXPORT_SYMBOL_GPL(cgroup_mutex);       /* only for lockdep */
 #else
 static DEFINE_MUTEX(cgroup_mutex);
 #endif
index 75dda1ea5026fdf7f8d179f31b5217348b501e0f..9d3f61566fecab2b035acf15741a853f6f7b4f25 100644 (file)
@@ -47,13 +47,13 @@ struct freezer {
 
 static inline struct freezer *cgroup_freezer(struct cgroup *cgroup)
 {
-       return container_of(cgroup_subsys_state(cgroup, freezer_subsys_id),
+       return container_of(cgroup_css(cgroup, freezer_subsys_id),
                            struct freezer, css);
 }
 
 static inline struct freezer *task_freezer(struct task_struct *task)
 {
-       return container_of(task_subsys_state(task, freezer_subsys_id),
+       return container_of(task_css(task, freezer_subsys_id),
                            struct freezer, css);
 }
 
index 1b9c31549797dcc4a6e443b9dfcae6d59f0827fc..be4512ba2c0cb0502edef8c3c2655b64f5be49c2 100644 (file)
@@ -117,14 +117,14 @@ struct cpuset {
 /* Retrieve the cpuset for a cgroup */
 static inline struct cpuset *cgroup_cs(struct cgroup *cgrp)
 {
-       return container_of(cgroup_subsys_state(cgrp, cpuset_subsys_id),
+       return container_of(cgroup_css(cgrp, cpuset_subsys_id),
                            struct cpuset, css);
 }
 
 /* Retrieve the cpuset for a task */
 static inline struct cpuset *task_cs(struct task_struct *task)
 {
-       return container_of(task_subsys_state(task, cpuset_subsys_id),
+       return container_of(task_css(task, cpuset_subsys_id),
                            struct cpuset, css);
 }
 
@@ -2724,7 +2724,7 @@ int proc_cpuset_show(struct seq_file *m, void *unused_v)
                goto out_free;
 
        rcu_read_lock();
-       css = task_subsys_state(tsk, cpuset_subsys_id);
+       css = task_css(tsk, cpuset_subsys_id);
        retval = cgroup_path(css->cgroup, buf, PAGE_SIZE);
        rcu_read_unlock();
        if (retval < 0)
index 1833bc5a84a73049b6e1f27caed87adfbdf44b2c..414c61f4d776f06dd098285b8b448d085c39a124 100644 (file)
@@ -340,8 +340,8 @@ struct perf_cgroup {
 static inline struct perf_cgroup *
 perf_cgroup_from_task(struct task_struct *task)
 {
-       return container_of(task_subsys_state(task, perf_subsys_id),
-                       struct perf_cgroup, css);
+       return container_of(task_css(task, perf_subsys_id),
+                           struct perf_cgroup, css);
 }
 
 static inline bool
@@ -7798,7 +7798,7 @@ static struct cgroup_subsys_state *perf_cgroup_css_alloc(struct cgroup *cont)
 static void perf_cgroup_css_free(struct cgroup *cont)
 {
        struct perf_cgroup *jc;
-       jc = container_of(cgroup_subsys_state(cont, perf_subsys_id),
+       jc = container_of(cgroup_css(cont, perf_subsys_id),
                          struct perf_cgroup, css);
        free_percpu(jc->info);
        kfree(jc);
index 9b1f2e533b95cf2532ffcadfc62476b18d9e27f5..323d907eac1ab2d310978bcc49dfb5c21c3b8006 100644 (file)
@@ -6761,7 +6761,7 @@ void sched_move_task(struct task_struct *tsk)
        if (unlikely(running))
                tsk->sched_class->put_prev_task(rq, tsk);
 
-       tg = container_of(task_subsys_state_check(tsk, cpu_cgroup_subsys_id,
+       tg = container_of(task_css_check(tsk, cpu_cgroup_subsys_id,
                                lockdep_is_held(&tsk->sighand->siglock)),
                          struct task_group, css);
        tg = autogroup_task_group(tsk, tg);
@@ -7086,7 +7086,7 @@ int sched_rt_handler(struct ctl_table *table, int write,
 /* return corresponding task_group object of a cgroup */
 static inline struct task_group *cgroup_tg(struct cgroup *cgrp)
 {
-       return container_of(cgroup_subsys_state(cgrp, cpu_cgroup_subsys_id),
+       return container_of(cgroup_css(cgrp, cpu_cgroup_subsys_id),
                            struct task_group, css);
 }
 
index dbb7e2cd95eba592f6b7878238ff12979e4c1aa0..4a210faaab778b9ba0db6032a827424a8130f5f8 100644 (file)
@@ -36,14 +36,14 @@ struct cpuacct {
 /* return cpu accounting group corresponding to this container */
 static inline struct cpuacct *cgroup_ca(struct cgroup *cgrp)
 {
-       return container_of(cgroup_subsys_state(cgrp, cpuacct_subsys_id),
+       return container_of(cgroup_css(cgrp, cpuacct_subsys_id),
                            struct cpuacct, css);
 }
 
 /* return cpu accounting group to which this task belongs */
 static inline struct cpuacct *task_ca(struct task_struct *tsk)
 {
-       return container_of(task_subsys_state(tsk, cpuacct_subsys_id),
+       return container_of(task_css(tsk, cpuacct_subsys_id),
                            struct cpuacct, css);
 }
 
index ef0a7b2439dde25bdd3d4ee54c4801364e09607d..471a56db05eaf4064a9c541e5bd295d2030ebd95 100644 (file)
@@ -665,9 +665,9 @@ extern int group_balance_cpu(struct sched_group *sg);
 /*
  * Return the group to which this tasks belongs.
  *
* We cannot use task_subsys_state() and friends because the cgroup
* subsystem changes that value before the cgroup_subsys::attach() method
* is called, therefore we cannot pin it and might observe the wrong value.
  *
  * The same is true for autogroup's p->signal->autogroup->tg, the autogroup
  * core changes this before calling sched_move_task().
index 9cea7de22ffbf351b8cc77eb40563543e38d59b7..50f213fc52c7d3ebfcf054bc62ac4ea6092dadff 100644 (file)
@@ -42,15 +42,13 @@ struct hugetlb_cgroup *hugetlb_cgroup_from_css(struct cgroup_subsys_state *s)
 static inline
 struct hugetlb_cgroup *hugetlb_cgroup_from_cgroup(struct cgroup *cgroup)
 {
-       return hugetlb_cgroup_from_css(cgroup_subsys_state(cgroup,
-                                                          hugetlb_subsys_id));
+       return hugetlb_cgroup_from_css(cgroup_css(cgroup, hugetlb_subsys_id));
 }
 
 static inline
 struct hugetlb_cgroup *hugetlb_cgroup_from_task(struct task_struct *task)
 {
-       return hugetlb_cgroup_from_css(task_subsys_state(task,
-                                                        hugetlb_subsys_id));
+       return hugetlb_cgroup_from_css(task_css(task, hugetlb_subsys_id));
 }
 
 static inline bool hugetlb_cgroup_is_root(struct hugetlb_cgroup *h_cg)
index d12ca6f3c2934bc83bd83c467ed672c7f352d172..b47bd3ad3c2b6674fa7840c5251d3a5e0bf7b3ef 100644 (file)
@@ -1037,8 +1037,7 @@ static void memcg_check_events(struct mem_cgroup *memcg, struct page *page)
 
 struct mem_cgroup *mem_cgroup_from_cont(struct cgroup *cont)
 {
-       return mem_cgroup_from_css(
-               cgroup_subsys_state(cont, mem_cgroup_subsys_id));
+       return mem_cgroup_from_css(cgroup_css(cont, mem_cgroup_subsys_id));
 }
 
 struct mem_cgroup *mem_cgroup_from_task(struct task_struct *p)
@@ -1051,7 +1050,7 @@ struct mem_cgroup *mem_cgroup_from_task(struct task_struct *p)
        if (unlikely(!p))
                return NULL;
 
-       return mem_cgroup_from_css(task_subsys_state(p, mem_cgroup_subsys_id));
+       return mem_cgroup_from_css(task_css(p, mem_cgroup_subsys_id));
 }
 
 struct mem_cgroup *try_get_mem_cgroup_from_mm(struct mm_struct *mm)
index 736a6011c2c88606cc7908fe429b14823be18625..7f1654d3cec7928ae13c76808b6b60f92507ca2e 100644 (file)
@@ -76,7 +76,7 @@ static struct vmpressure *work_to_vmpressure(struct work_struct *work)
 
 static struct vmpressure *cg_to_vmpressure(struct cgroup *cg)
 {
-       return css_to_vmpressure(cgroup_subsys_state(cg, mem_cgroup_subsys_id));
+       return css_to_vmpressure(cgroup_css(cg, mem_cgroup_subsys_id));
 }
 
 static struct vmpressure *vmpressure_parent(struct vmpressure *vmpr)
index e533259dce3ccad8a04cc095fa0056b8693fde70..ccf852311987c2ddd6d8b22fd3042cda18f77409 100644 (file)
@@ -31,7 +31,7 @@
 
 static inline struct cgroup_netprio_state *cgrp_netprio_state(struct cgroup *cgrp)
 {
-       return container_of(cgroup_subsys_state(cgrp, net_prio_subsys_id),
+       return container_of(cgroup_css(cgrp, net_prio_subsys_id),
                            struct cgroup_netprio_state, css);
 }
 
index 3a294eb98d6178733edc49c98da4069ccf643a39..5ee72a001df0b68c4bd25c70bfc75cf13dccc95f 100644 (file)
 
 static inline struct cgroup_cls_state *cgrp_cls_state(struct cgroup *cgrp)
 {
-       return container_of(cgroup_subsys_state(cgrp, net_cls_subsys_id),
+       return container_of(cgroup_css(cgrp, net_cls_subsys_id),
                            struct cgroup_cls_state, css);
 }
 
 static inline struct cgroup_cls_state *task_cls_state(struct task_struct *p)
 {
-       return container_of(task_subsys_state(p, net_cls_subsys_id),
+       return container_of(task_css(p, net_cls_subsys_id),
                            struct cgroup_cls_state, css);
 }
 
index e8aad69f0d696c70b21dc8af16b0d28d990b3eda..87a0a037fbd655eb15e44928eb918e55e0d55d07 100644 (file)
@@ -58,12 +58,12 @@ static inline struct dev_cgroup *css_to_devcgroup(struct cgroup_subsys_state *s)
 
 static inline struct dev_cgroup *cgroup_to_devcgroup(struct cgroup *cgroup)
 {
-       return css_to_devcgroup(cgroup_subsys_state(cgroup, devices_subsys_id));
+       return css_to_devcgroup(cgroup_css(cgroup, devices_subsys_id));
 }
 
 static inline struct dev_cgroup *task_devcgroup(struct task_struct *task)
 {
-       return css_to_devcgroup(task_subsys_state(task, devices_subsys_id));
+       return css_to_devcgroup(task_css(task, devices_subsys_id));
 }
 
 struct cgroup_subsys devices_subsys;
@@ -678,7 +685,7 @@ extern struct mutex cgroup_mutex;
 
 /**
- * task_subsys_state_check - obtain css for (task, subsys) w/ extra access conds
+ * task_css_check - obtain css for (task, subsys) w/ extra access conds
  * @task: the target task
  * @subsys_id: the target subsystem ID
@@ -701,22 +708,22 @@ static inline struct css_set *task_css_set(struct task_struct *task)
 
 /**
- * task_subsys_state - obtain css for (task, subsys)
+ * task_css - obtain css for (task, subsys)
  * @task: the target task
  * @subsys_id: the target subsystem ID
@@ -665,9 +665,9 @@ extern int group_balance_cpu(struct sched_group *sg);
  * Return the group to which this tasks belongs.
  *
- * We cannot use task_subsys_state() and friends because the cgroup
- * subsystem changes that value before the cgroup_subsys::attach() method
- * is called, therefore we cannot pin it and might observe the wrong value.
+ * We cannot use task_css() and friends because the cgroup subsystem
+ * changes that value before the cgroup_subsys::attach() method is called,
+ * therefore we cannot pin it and might observe the wrong value.
  *
  * The same is true for autogroup's p->signal->autogroup->tg, the autogroup